This module contains analysis for paper
[What is a robust stochastic volatility model](https://papers.ssrn.com/sol3/papers.cfm?abstract_id=4647027) by Artur Sepp and Parviz Rakhmonov

All figures in the paper are produced by unittests in
```python 
article_figures.py
```
https://github.com/ArturSepp/StochVolModels/blob/main/my_papers/volatility_models/article_figures.py

See the description of data and analysis in the paper.
